import logging
from typing import Optional, Tuple

import torch
from omegaconf import DictConfig

from empiricalprivacyestimation.util.types import DataPoint


def insert_attacked_sample(
    cfg: DictConfig,
    data: torch.Tensor,
    labels: torch.Tensor,
    attack_point: Optional[DataPoint],
)-> Tuple[torch.Tensor, torch.Tensor]:
    """
    Insert the attack point into the data and labels.
    :param cfg: The hyperparameters of the experiment
    :param data: The data to be poisoned
    :param labels: The labels to be poisoned
    :param attack_point: The attack point
    :return:
    """
    device = torch.device(cfg.training_params.device)

    if not attack_point:
        logging.info("No poisoning sample provided, falling back on ideal poisoning")
        return data, labels
    data = torch.cat(
        [
            data.to(device),
            attack_point[0].to(device),
        ],
        dim=0,
    ).to(device)
    labels = torch.cat(
        [
            labels.to(device),
            attack_point[1].to(device),
        ],
        dim=0,
    ).to(device)
    return data, labels
