import logging
from typing import Tuple

from omegaconf import DictConfig
from torch.utils.data import DataLoader

from .cifar10 import get_cifar10
from .gaussian_data_outlier import get_gaussian_dataloaders
from .housing import get_housing_data
from .iris import get_iris
from ..util.types import DataPoint


def get_dataloaders(
    cfg: DictConfig,
) -> Tuple[DataLoader, DataLoader, DataPoint]:
    if cfg.training_params.poisson_sampled_dataset:
        logging.info("Using poisson sampled dataset")
    else:
        logging.info("Using deterministic sampled_dataset")

    if cfg.data.name == "iris":
        return get_iris(cfg)

    if cfg.data.name == "syntethic-gaussians":
        return get_gaussian_dataloaders(
            cfg=cfg,
            batch_size=cfg.training_params.batch_size,
            max_per_sample_grad_norm=cfg.privacy.C,
            no_of_samples_per_class_train=cfg.data.no_of_samples_per_class_train,
            no_of_samples_per_class_test=cfg.data.no_of_samples_per_class_test,
            test_batch_size=cfg.training_params.test_batch_size,
            class_center_1=cfg.data.class_center_1,
            class_center_2=cfg.data.class_center_2,
            data_variance=cfg.data.data_variance,
            number_of_regular_dimensions=cfg.data.number_of_regular_dimensions,
        )

    if cfg.data.name == "cifar10":
        return get_cifar10(cfg)

    if cfg.data.name == "housing":
        return get_housing_data(cfg)
