from typing import List
from .clopper_pearson import get_bounds_clopper
from .gdp_cp import get_bounds as get_bounds_ge_cp
from omegaconf import DictConfig


def get_privacy_auditing_steps(cfg: DictConfig) -> List[int]:
    return list(range(1, cfg.training_params.total_no_of_steps + 1))


def get_epsilon_estimation(cfg: DictConfig, fnr: float, fpr: float) -> float:
    if cfg.empirical_epsilon.method == "clopper-pearson":
        return get_bounds_clopper(fnr=fnr, fpr=fpr, delta=cfg.privacy.delta)

    if cfg.empirical_epsilon.method == "gdp-cp":
        return get_bounds_ge_cp(fnr=fnr, fpr=fpr, delta=cfg.privacy.delta)

    raise ValueError(
        f"Unknown epsilon estimation method: {cfg.empirical_epsilon.method}"
    )
