import numpy as np
from scipy.optimize import brentq
from scipy.stats import norm


def get_bounds(
    fnr: float,
    fpr: float,
    eps_tol=1e-12,
    delta: float = 1e-5
):
    mean = norm.ppf(1.0 - fnr) - norm.ppf(fpr)
    def search_fn(eps):
        return (
                delta
                - norm.cdf(-eps / mean + mean / 2)
                + np.exp(eps) * norm.cdf(-eps / mean - mean / 2)
        )

    return brentq(search_fn, a=-25, b=200, xtol=eps_tol)
