import logging

import torch
from omegaconf import DictConfig
from torch.nn import Module

from .alexnet import AlexNetCIFAR10 as alexnet
from .fcnn import FCNN
from .linear_model import LogisticRegression
from .logistic_reg_iris import LogisticRegressionIris
from .resnet18 import get_resnet18
from .vision import Net


def get_model(cfg: DictConfig) -> Module:
    device = torch.device(cfg.training_params.device)


    if hasattr(cfg.training_params, "seed") and cfg.training_params.seed is not None:
        logging.info("Using fixed seed for model init")

        # set the random seed accordingly
        torch.manual_seed(cfg.training_params.seed)
        torch.cuda.manual_seed(cfg.training_params.seed)
        torch.cuda.manual_seed_all(cfg.training_params.seed)

    if cfg.model.name == "LogisticRegression":
        model = LogisticRegression(cfg).to(device=device)
    elif cfg.model.name == "alexnet":
        model = alexnet().to(device=device)
    elif cfg.model.name == "LogisticRegressionIris":
        model = LogisticRegressionIris().to(device=device)
    elif cfg.model.name == "resnet18":
        model = get_resnet18(cfg).to(device=device)
    elif cfg.model.name == "cnn":
        model = Net(cfg).to(device=device)
    elif cfg.model.name == "fcnn":
        model = FCNN().to(device=device)
    else:
        raise ValueError(f"Unknown model name: {cfg.model.name}")

    if hasattr(cfg.training_params, "seed") and cfg.training_params.seed is not None:
        # start from fresh seed
        torch.manual_seed(torch.seed())
        torch.cuda.manual_seed(torch.seed())
        torch.cuda.manual_seed_all(torch.seed())

    return model