from omegaconf import DictConfig
import numpy as np
from opacus.accountants import PRVAccountant
from tqdm import tqdm
import logging

def get_privacy_guarantees(cfg: DictConfig) -> np.ndarray:
    epsilons = [0]
    accountant = PRVAccountant()

    if cfg.accounting.canary_sampling.startswith("sample_rate"):
        logging.info("Computing privacy guarantees given a sample_rate")
        for i in tqdm(range(cfg.training_params.total_no_of_steps)):
            accountant.step(
                noise_multiplier=cfg.privacy.sigma, sample_rate=cfg.privacy.sample_rate
            )
            eps = accountant.get_epsilon(delta=cfg.privacy.delta)
            epsilons.append(eps)
    elif cfg.accounting.canary_sampling.startswith("every"):
        k = int(cfg.accounting.canary_sampling.split("@")[1])

        for i in tqdm(range(cfg.training_params.total_no_of_steps)):
            if i % k == 0:
                accountant.step(
                    noise_multiplier=cfg.privacy.sigma, sample_rate=1
                )
                eps = accountant.get_epsilon(delta=cfg.privacy.delta)
            epsilons.append(eps)
        logging.info(f"Computing privacy guarantees at every k step")
    epsilons = np.array(epsilons)
    logging.info(f"Privacy guarantees: {epsilons}")
    return epsilons