import hydra
import numpy as np
from matplotlib import pyplot as plt

def plot_CI_curves(samples, xlabel, ylabel, filename, C):
    """
    Plot the confidence interval of the samples.
    """

    hydra_cfg = hydra.core.hydra_config.HydraConfig.get()
    out_dir = hydra_cfg["runtime"]["output_dir"]

    plt.cla()
    plt.clf()
    per_sample_means = np.array(samples)
    means = np.mean(per_sample_means, axis=0).squeeze()
    stds = np.std(per_sample_means, axis=0)
    lower = means - 2 * stds
    upper = means + 2 * stds
    plt.plot(means, label="Canary Sensitivity", color="r")
    plt.fill_between(
        np.arange(means.shape[0]),
        lower,
        upper,
        color="r",
        alpha=0.2,
    )
    plt.ylim((0, C + 0.2))
    plt.axhline(y=C, color="b", linestyle="--", label="C")
    plt.xlabel(xlabel)
    plt.ylabel(ylabel)

    plt.legend()
    plt.savefig(f"{out_dir}/{filename}")

    plt.clf()
    plt.cla()