from matplotlib import pyplot as plt
from scipy.stats.distributions import beta
import numpy as np


def draw_probability_distribution(k: int, N: int) -> None:
    fig, ax = plt.subplots(1, 1)
    a = 1 / 2 + k
    b = 1 / 2 + N - k
    rv = beta(a, b)

    x = np.linspace(beta.ppf(0.01, a, b), beta.ppf(0.99, a, b), 100)
    ax.plot(x, rv.pdf(x), "k-", lw=2, label="frozen pdf")
    ax.legend()
    fig.show()


def draw_posteriors(tp: int, tn: int, fp: int, fn: int) -> None:
    x1 = np.linspace(
        beta.ppf(0.01, fn + 1 / 2, tp + 1 / 2),
        beta.ppf(0.99, fn + 1 / 2, tp + 1 / 2),
        100,
    )
    x2 = np.linspace(
        beta.ppf(0.01, fp + 1 / 2, tn + 1 / 2),
        beta.ppf(0.99, fp + 1 / 2, tn + 1 / 2),
        100,
    )

    dist1 = beta.pdf(x1, 1 / 2 + fn, 1 / 2 + tp)
    dist2 = beta.pdf(x1, 1 / 2 + fp, 1 / 2 + tn)

    fig, axs = plt.subplots(ncols=2)
    axs[0].plot(x1, dist1, "k-", lw=2, label="frozen pdf")
    axs[1].plot(x2, dist2, "k-", lw=2, label="frozen pdf")
    fig.show()
