from typing import Tuple

import torch

from empiricalprivacyestimation.util.loss_fn import get_loss_fn


def measure_sample_sensitivity(cfg, sample: Tuple[torch.Tensor, torch.Tensor], model: torch.nn.Module) -> float:
    model.train()
    device = torch.device(cfg.training_params.device)
    X, y = sample
    X, y = X.to(device), y.to(device)
    model = model.to(device)
    criterion, reduction = get_loss_fn(cfg)
    
    if cfg.model.name == "LogisticRegression":
        output = model(X, stable=True)
    else:
        output = model(X)

    loss = criterion(output, y)
    loss.backward()

    # compute gradient norm
    grads = [
        param.grad.detach().flatten()
        for param in model.parameters()
        if param.grad is not None
    ]
    grad_norm = torch.cat(grads).norm(p=2)

    return grad_norm

