import hydra
from typing import Optional
from matplotlib import pyplot
from torch import Tensor


def plot_gradient_norm_histogram(gradient: Tensor, filename: str) -> Tensor:
    hydra_cfg = hydra.core.hydra_config.HydraConfig.get()
    out_dir = hydra_cfg["runtime"]["output_dir"]
    pyplot.xscale("log", base=2)
    pyplot.hist(gradient.numpy(), bins=500)
    pyplot.title("Per Parameter Gradient Norm Distribution (L2 Norm)")
    pyplot.savefig(f"{out_dir}/{filename}")
    pyplot.cla()
    pyplot.clf()


def plot_histogram(
    in_samples: Tensor,
    out_samples: Tensor,
    filename: str,
    threshold: Optional[float] = None,
    in_label: str = "in samples",
    out_label: str = "out samples",
) -> None:
    pyplot.hist(in_samples.numpy(), alpha=0.5, label=in_label, bins=50)
    pyplot.hist(out_samples.numpy(), alpha=0.5, label=out_label, bins=50)
    if threshold:
        pyplot.axvline(threshold, label="threshold")
    pyplot.legend(loc="upper right")
    pyplot.savefig(filename)
    pyplot.clf()
    pyplot.cla()
